# Maintenance (Sequential, Satisficing)

## Domain Description

This is a simple planning/scheduling problem.
There are mechanics/equipment that on any day may work at one of several airports (hubs), where the maintenance facilities are present.
There are airplanes, each of which has to be checked or repaired during the given time period.
The airplanes are guaranteed to visit some of the airports on given days.
The problem is to schedule the presence of the mechanics/equipment so that each plane will get maintenance once during the time period.

## Authors

Jussi Rintanen

## Original File Names

| file             | original name                      |
|------------------|------------------------------------|
| domain.pddl      | domain.pddl                        |
| instance-1.pddl  | maintenance.1.3.060.180.5-000.pddl |
| instance-2.pddl  | maintenance.1.3.060.180.5-001.pddl |
| instance-3.pddl  | maintenance.1.3.060.180.5-002.pddl |
| instance-4.pddl  | maintenance.1.3.100.300.5-000.pddl |
| instance-5.pddl  | maintenance.1.3.100.300.5-001.pddl |
| instance-6.pddl  | maintenance.1.3.100.300.7-000.pddl |
| instance-7.pddl  | maintenance.1.3.100.300.7-001.pddl |
| instance-8.pddl  | maintenance.1.3.100.300.7-002.pddl |
| instance-9.pddl  | maintenance.1.3.150.500.6-001.pddl |
| instance-10.pddl | maintenance.1.3.200.500.5-001.pddl |
| instance-11.pddl | maintenance.1.3.200.500.5-002.pddl |
| instance-12.pddl | maintenance.1.3.200.700.7-000.pddl |
| instance-13.pddl | maintenance.1.3.200.700.7-001.pddl |
| instance-14.pddl | maintenance.1.3.200.700.7-002.pddl |
| instance-15.pddl | maintenance.1.3.200.900.5-000.pddl |
| instance-16.pddl | maintenance.1.3.200.900.5-001.pddl |
| instance-17.pddl | maintenance.1.3.200.900.5-002.pddl |
| instance-18.pddl | maintenance.1.3.200.900.8-000.pddl |
| instance-19.pddl | maintenance.1.3.200.900.8-001.pddl |
| instance-20.pddl | maintenance.1.3.200.900.8-002.pddl |
